import gradio as gr
from transformers import ViTImageProcessor, ViTModel

processor = ViTImageProcessor.from_pretrained('google/vit-large-patch16-224-in21k')
model = ViTModel.from_pretrained('google/vit-large-patch16-224-in21k')

def image_classification(image):
    inputs = processor(images=image, return_tensors="pt")
    outputs = model(**inputs)
    logits = outputs.logits
    predicted_label = logits.argmax(-1).item()

    return model.config.id2label[predicted_label]

demo = gr.Interface(fn=image_classification, 
                    inputs=gr.Image(), 
                    outputs=gr.Label(num_top_classes=1),
                    title = "图像分类",
                    examples = ['dog.jpeg'])


if __name__ == "__main__":
    demo.queue(concurrency_count=3)
    demo.launch(server_name = "0.0.0.0", server_port = 7027)
